@@ -72,7 +72,7 @@ class SubQuery(object):
         for expression in selects:
             if '__' in expression:
                 field, operator = expression.split('__')
-                if operator in ['count', 'sum', 'avg']:
+                if operator in ['count', 'sum', 'avg', 'max', 'min']:
                     param = getattr(fn, operator)(getattr(model, field)).alias(expression)
                     select_params.append(param)
                 elif operator == 'count_distinct':
@@ -421,7 +421,7 @@ class RestSqlClient(object):
                     sort_methods.append(False)
                 else:
                     sort_methods.append(True)
-            data_frame.sort_values(by=sort_list, ascending=sort_methods)
+            data_frame = data_frame.sort_values(by=sort_list, ascending=sort_methods)
 
         # 5、合并后limit处理
         limit = query.get('limit', 1000)
